@@ -78,8 +78,8 @@ typedef struct pkgconf_cross_personality_ pkgconf_cross_personality_t;
 #define PKGCONF_FOREACH_LIST_ENTRY_REVERSE(tail, value) \
 	for ((value) = (tail); (value) != NULL; (value) = (value)->prev)
 
-#define LIBPKGCONF_VERSION	10603
-#define LIBPKGCONF_VERSION_STR	"1.6.3"
+#define LIBPKGCONF_VERSION	10801
+#define LIBPKGCONF_VERSION_STR	"1.8.1"
 
 struct pkgconf_fragment_ {
 	pkgconf_node_t iter;
@@ -202,6 +202,9 @@ struct pkgconf_cross_personality_ {
 	pkgconf_list_t filter_includedirs;
 
 	char *sysroot_dir;
+
+	bool want_default_static;
+	bool want_default_pure;
 };
 
 /* client.c */
@@ -228,6 +231,7 @@ PKGCONF_API void pkgconf_client_dir_list_build(pkgconf_client_t *client, const p
 /* personality.c */
 PKGCONF_API pkgconf_cross_personality_t *pkgconf_cross_personality_default(void);
 PKGCONF_API pkgconf_cross_personality_t *pkgconf_cross_personality_find(const char *triplet);
+PKGCONF_API void pkgconf_cross_personality_deinit(pkgconf_cross_personality_t *personality);
 
 #define PKGCONF_IS_MODULE_SEPARATOR(c) ((c) == ',' || isspace ((unsigned int)(c)))
 #define PKGCONF_IS_OPERATOR_CHAR(c) ((c) == '<' || (c) == '>' || (c) == '!' || (c) == '=')
@@ -247,6 +251,8 @@ PKGCONF_API pkgconf_cross_personality_t *pkgconf_cross_personality_find(const ch
 #define PKGCONF_PKG_PKGF_DONT_RELOCATE_PATHS		0x0800
 #define PKGCONF_PKG_PKGF_SIMPLIFY_ERRORS		0x1000
 #define PKGCONF_PKG_PKGF_DONT_FILTER_INTERNAL_CFLAGS	0x2000
+#define PKGCONF_PKG_PKGF_DONT_MERGE_SPECIAL_FRAGMENTS	0x4000
+#define PKGCONF_PKG_PKGF_FDO_SYSROOT_RULES		0x8000
 
 #define PKGCONF_PKG_DEPF_INTERNAL		0x1
 
