@@ -99,8 +99,8 @@ pkgconf_pkg_parser_version_func(const pkgconf_client_t *client, pkgconf_pkg_t *p
 	/* cut at any detected whitespace */
 	p = pkgconf_tuple_parse(client, &pkg->vars, value);
 
-	len = strcspn(p, " \t\r\n");
-	if (len)
+	len = strcspn(p, " \t");
+	if (len != strlen(p))
 	{
 		i = p + (ptrdiff_t) len;
 		*i = '\0';
@@ -214,6 +214,37 @@ determine_prefix(const pkgconf_pkg_t *pkg, char *buf, size_t buflen)
 	return buf;
 }
 
+/*
+ * Takes a real path and converts it to a pkgconf value. This means normalizing
+ * directory separators and escaping things (only spaces covered atm).
+ *
+ * This is useful for things like prefix/pcfiledir which might get injected
+ * at runtime and are not sourced from the .pc file.
+ *
+ * "C:\foo bar\baz" -> "C:/foo\ bar/baz"
+ * "/foo bar/baz" -> "/foo\ bar/baz"
+ */
+static char *
+convert_path_to_value(const char *path)
+{
+	char *buf = calloc((strlen(path) + 1) * 2, 1);
+	char *bptr = buf;
+	const char *i;
+
+	for (i = path; *i != '\0'; i++)
+	{
+		if (*i == PKG_DIR_SEP_S)
+			*bptr++ = '/';
+		else if (*i == ' ') {
+			*bptr++ = '\\';
+			*bptr++ = *i;
+		} else
+			*bptr++ = *i;
+	}
+
+	return buf;
+}
+
 static void
 remove_additional_separators(char *buf)
 {
@@ -238,16 +269,6 @@ remove_additional_separators(char *buf)
 static void
 canonicalize_path(char *buf)
 {
-#ifdef _WIN32
-	char *p = buf;
-
-	while (*p) {
-		if (*p == '\\')
-			*p = '/';
-		p++;
-	}
-#endif
-
 	remove_additional_separators(buf);
 }
 
@@ -276,7 +297,11 @@ pkgconf_pkg_parser_value_set(void *opaque, const size_t lineno, const char *keyw
 	 * which is broken when redefining the prefix. We try to outsmart the
 	 * file and rewrite any directory that starts with the same prefix.
 	 */
-	if (pkg->owner->flags & PKGCONF_PKG_PKGF_REDEFINE_PREFIX && pkg->orig_prefix
+	if (strcmp(keyword, pkg->owner->prefix_varname) || !(pkg->owner->flags & PKGCONF_PKG_PKGF_REDEFINE_PREFIX))
+	{
+		pkgconf_tuple_add(pkg->owner, &pkg->vars, keyword, value, true);
+	}
+	else if (pkg->owner->flags & PKGCONF_PKG_PKGF_REDEFINE_PREFIX && pkg->orig_prefix
 	    && is_path_prefix_equal(canonicalized_value, pkg->orig_prefix->value, strlen(pkg->orig_prefix->value)))
 	{
 		char newvalue[PKGCONF_ITEM_SIZE];
@@ -285,8 +310,6 @@ pkgconf_pkg_parser_value_set(void *opaque, const size_t lineno, const char *keyw
 		pkgconf_strlcat(newvalue, canonicalized_value + strlen(pkg->orig_prefix->value), sizeof newvalue);
 		pkgconf_tuple_add(pkg->owner, &pkg->vars, keyword, newvalue, false);
 	}
-	else if (strcmp(keyword, pkg->owner->prefix_varname) || !(pkg->owner->flags & PKGCONF_PKG_PKGF_REDEFINE_PREFIX))
-		pkgconf_tuple_add(pkg->owner, &pkg->vars, keyword, value, true);
 	else
 	{
 		char pathbuf[PKGCONF_ITEM_SIZE];
@@ -294,8 +317,10 @@ pkgconf_pkg_parser_value_set(void *opaque, const size_t lineno, const char *keyw
 
 		if (relvalue != NULL)
 		{
+			char *prefix_value = convert_path_to_value(relvalue);
 			pkg->orig_prefix = pkgconf_tuple_add(pkg->owner, &pkg->vars, "orig_prefix", canonicalized_value, true);
-			pkg->prefix = pkgconf_tuple_add(pkg->owner, &pkg->vars, keyword, relvalue, false);
+			pkgconf_tuple_add_global(pkg->owner, keyword, prefix_value);
+			free(prefix_value);
 		}
 		else
 			pkgconf_tuple_add(pkg->owner, &pkg->vars, keyword, value, true);
@@ -376,18 +401,37 @@ pkgconf_pkg_new_from_file(pkgconf_client_t *client, const char *filename, FILE *
 	pkg->owner = client;
 	pkg->filename = strdup(filename);
 	pkg->pc_filedir = pkg_get_parent_dir(pkg);
-	pkgconf_tuple_add(client, &pkg->vars, "pcfiledir", pkg->pc_filedir, true);
+
+	char *pc_filedir_value = convert_path_to_value(pkg->pc_filedir);
+	pkgconf_tuple_add(client, &pkg->vars, "pcfiledir", pc_filedir_value, true);
+	free(pc_filedir_value);
+
+	/* If pc_filedir is outside of sysroot_dir, clear pc_filedir
+	 * See https://github.com/pkgconf/pkgconf/issues/213
+	 */
+	if (client->sysroot_dir && strncmp(pkg->pc_filedir, client->sysroot_dir, strlen(client->sysroot_dir)))
+	{
+		free(client->sysroot_dir);
+		client->sysroot_dir = NULL;
+		pkgconf_client_set_sysroot_dir(client, NULL);
+	}
 
 	/* make module id */
 	if ((idptr = strrchr(pkg->filename, PKG_DIR_SEP_S)) != NULL)
 		idptr++;
-#ifdef _WIN32
-	else if ((idptr = strrchr(pkg->filename, '/')) != NULL)
-		idptr++;
-#endif
 	else
 		idptr = pkg->filename;
 
+#ifdef _WIN32
+	/* On Windows, both \ and / are allowed in paths, so we have to chop both.
+	 * strrchr() took us to the last \ in that case, so we just have to see if
+	 * it is followed by a /.  If so, lop it off.
+	 */
+	char *mungeptr;
+	if ((mungeptr = strrchr(idptr, '/')) != NULL)
+		idptr = ++mungeptr;
+#endif
+
 	pkg->id = strdup(idptr);
 	idptr = strrchr(pkg->id, '.');
 	if (idptr)
@@ -526,14 +570,15 @@ pkgconf_pkg_try_specific_path(pkgconf_client_t *client, const char *path, const
 
 	PKGCONF_TRACE(client, "trying path: %s for %s", path, name);
 
-	snprintf(locbuf, sizeof locbuf, "%s/%s" PKG_CONFIG_EXT, path, name);
-	snprintf(uninst_locbuf, sizeof uninst_locbuf, "%s/%s-uninstalled" PKG_CONFIG_EXT, path, name);
+	snprintf(locbuf, sizeof locbuf, "%s%c%s" PKG_CONFIG_EXT, path, PKG_DIR_SEP_S, name);
+	snprintf(uninst_locbuf, sizeof uninst_locbuf, "%s%c%s-uninstalled" PKG_CONFIG_EXT, path, PKG_DIR_SEP_S, name);
 
 	if (!(client->flags & PKGCONF_PKG_PKGF_NO_UNINSTALLED) && (f = fopen(uninst_locbuf, "r")) != NULL)
 	{
 		PKGCONF_TRACE(client, "found (uninstalled): %s", uninst_locbuf);
 		pkg = pkgconf_pkg_new_from_file(client, uninst_locbuf, f);
-		pkg->flags |= PKGCONF_PKG_PROPF_UNINSTALLED;
+		if (pkg != NULL)
+			pkg->flags |= PKGCONF_PKG_PROPF_UNINSTALLED;
 	}
 	else if ((f = fopen(locbuf, "r")) != NULL)
 	{
@@ -753,7 +798,7 @@ out:
  *
  *    :param char* a: The first version to compare in the pair.
  *    :param char* b: The second version to compare in the pair.
- *    :return: -1 if the first version is greater, 0 if both versions are equal, 1 if the second version is greater.
+ *    :return: -1 if the first version is less than, 0 if both versions are equal, 1 if the second version is less than.
  *    :rtype: int
  */
 int
@@ -768,10 +813,10 @@ pkgconf_compare_version(const char *a, const char *b)
 
 	/* optimization: if version matches then it's the same version. */
 	if (a == NULL)
-		return 1;
+		return -1;
 
 	if (b == NULL)
-		return -1;
+		return 1;
 
 	if (!strcasecmp(a, b))
 		return 0;
@@ -792,9 +837,9 @@ pkgconf_compare_version(const char *a, const char *b)
 		if (*one == '~' || *two == '~')
 		{
 			if (*one != '~')
-				return -1;
-			if (*two != '~')
 				return 1;
+			if (*two != '~')
+				return -1;
 
 			one++;
 			two++;
@@ -860,8 +905,8 @@ pkgconf_compare_version(const char *a, const char *b)
 		}
 
 		ret = strcmp(one, two);
-		if (ret)
-			return ret;
+		if (ret != 0)
+			return ret < 0 ? -1 : 1;
 
 		*str1 = oldch1;
 		*str2 = oldch2;
